# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class EmailMessageListStatus(StrEnum):
    """
    * `queued` - Queued
    * `sent` - Sent
    * `failed` - Failed
    """

    QUEUED = "queued"
    SENT = "sent"
    FAILED = "failed"



